-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class ANIMATION_SEQUENTIAL

inherit
	ANIMATION

create
	make

feature {NONE} -- Creation

	make (sequence: COLLECTION [IMAGE]) is
		require
			sequence /= Void
			sequence.count >= 1
		local
			i: ITERATOR [IMAGE]
		do
			create image_list.from_collection (sequence)
			cursor := image_list.get_new_iterator
			i := image_list.get_new_iterator
			from
				i.start
				width := 0
				height := 0
			until i.is_off loop
				width := width.max (i.item.width)
				height := height.max (i.item.height)
				i.next
			end
		end

feature -- Access

	item: IMAGE is
		do
			if not cursor.is_off then
				Result := cursor.item
			else
				Result := image_list.last
			end
		end

	width, height: INTEGER

feature -- Operations

	start is
		do
			cursor.start
		end

	next is
		do
			if not cursor.is_off then
				cursor.next
			else
				unchanged := True
			end
		end

feature {NONE} -- Representation

	image_list: ARRAY[IMAGE]

	cursor: ITERATOR[IMAGE]

invariant
	image_list /= Void
	image_list.count >= 1
	cursor /= Void

end -- class ANIMATION_SEQUENTIAL