-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class SDL_BITMAP_FONT
	-- SDL_BASED Bitmapped font

inherit
	BITMAP_FONT
	SDL_IMAGE
		rename
			make as make_image
			is_compatible as is_compatible_image
			show as show_image
		end

create
	make

feature {NONE} -- Creation

	relative_spacing: REAL is 0.2
		-- Space left between lines (space = spacing * height [pixels])

	make (filename: STRING) is
		require
			filename_not_void: filename /= Void
		do
			make_from_file (filename)
			create chr_areas.make(33,128)
			parse
			remove_alpha
			spacing := (relative_spacing * height).rounded
		end -- make

	parse is
		local
			pixel, last_pixel, px, left, i: INTEGER
			area: RECTANGLE
		do
			last_pixel := pixel_key;
			from
				px := 0
				i := 33
			until px = width loop
				pixel := get_pixel (px, 0)
				if pixel /= pixel_key and last_pixel = pixel_key then
					left := px
				elseif pixel = pixel_key and last_pixel /= pixel_key then
					area.set_with_size (left, 0, px - left, height)
					chr_areas.put (area, i)
					i := i + 1
				end
				px := px + 1
				last_pixel := pixel
			end
		end

	pixel_key: INTEGER is
		once
			Result := SDL_MapRGB (to_external, 255, 0, 255)
		end

feature -- Access

	is_compatible (i: IMAGE): BOOLEAN is
		local
			img: SDL_IMAGE
		do
			img ?= i
			Result := img /= Void
		end

	new_image (w, h: INTEGER): IMAGE is
			-- New compatible image of `w'x`h'
		do
			create {SDL_IMAGE}Result.make_transparent (w, h)
		end

	char_width(chr: CHARACTER):INTEGER is
		do
			if chr = ' ' then
				Result := chr_areas.item(('e').code).width;
			elseif chr_areas.valid_index (chr.code) then
				Result := chr_areas.item (chr.code).width;
			end
		end

	show (text: STRING): IMAGE is
		do
			create {SDL_IMAGE}Result.make_transparent (width_of (text), height)
			show_at (Result, 0, 0, text)
		end

feature -- Operations

	show_at (img: IMAGE; x, y: INTEGER; text: STRING) is
		local
			chr_x: INTEGER
			i: ITERATOR[CHARACTER]
			s_img: SDL_IMAGE
		do
			s_img ?= img
			from
				i := text.get_new_iterator
				chr_x := x
			until
				i.is_off
			loop
				if i.item /= ' ' then
					blit (s_img, chr_x, y, chr_areas.item(i.item.code))
				end
				chr_x := chr_x + char_width(i.item)
				i.next
			end
		end

feature {NONE} -- Representation

	chr_areas: ARRAY [RECTANGLE]

end -- class SDL_BITMAP_FONT
