-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class SDL_IMAGE

inherit
	IMAGE
	SDL_SURFACE
		rename
			make_from_img as make_from_file
		end
	SDL_SCREEN_ACCESS

create
	make, make_transparent, make_from_file, make_from_screen, make_from_surface

feature {NONE} -- Creation

	make_from_screen (region: RECTANGLE) is
		do
			make (region.width, region.height)
			screen.blit (Current, 0, 0, region)
		end

feature -- Access

	is_compatible (i: IMAGE): BOOLEAN is
		local
			image: SDL_IMAGE
		do
			image ?= i
			Result := image /= Void
		end

feature -- Operations

	show (i: IMAGE; x, y: INTEGER) is
		local
			image: SDL_IMAGE
		do
			image ?= i
			blit_fast (image, x, y)
		end

	show_region (i: IMAGE; region: RECTANGLE; x, y: INTEGER) is
		local
			image: SDL_IMAGE
		do
			image ?= i
			blit (image, x, y, region)
		end

feature {SDL_IMAGE_ACCESS} -- Representation

	image_data: SDL_SURFACE is
		obsolete "Now use SDL_IMAGES instead of SDL_SURFACES"
		do Result := Current end

end -- class SDL_IMAGE
