-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
deferred class SDL_SCREEN_ACCESS

feature -- Access

	screen: SDL_SURFACE is
			-- Screen surface
		do
			Result := screen_surface_memo.item
		end

	is_videomode_set: BOOLEAN is
			-- True after setting screen
		do
			Result := screen /= Void
		end

feature -- Operations

	set_videomode (wid, hgt, bpp: INTEGER; fullscreen: BOOLEAN) is
		require
			not_videomode_set: not is_videomode_set
			valid_size: wid > 0 and hgt > 0
			valid_bpp: bpp = 16 or bpp = 24 or bpp = 32
		local
			s: SDL_SURFACE
		do
			screen_memo.set_item (SDL_SCREEN_set_videomode
				(wid, hgt, bpp, fullscreen))
				check not screen_memo.item.is_null end
			create s.make_from_surface (screen_memo.item)
			s.dont_release
			screen_surface_memo.set_item (s)
		ensure
			is_videomode_set
		end

	refresh (area: RECTANGLE) is
			-- Make visible operations made over `area'
		local
			a, d: RECTANGLE
		do
			d.set_with_size (0, 0, screen.width, screen.height)
			a := area * d
			SDL_UpdateRect (screen_memo.item, a.x, a.y, a.width, a.height)
		end

feature {NONE} -- Representation

	screen_memo: REFERENCE [POINTER] is
			-- shared screen pointer is stored here
		once
			create Result
		end

	screen_surface_memo: REFERENCE [SDL_SURFACE] is
			-- shared screen surface is stored here
		once
			create Result
		end

feature {NONE} -- External operations

	SDL_SCREEN_set_videomode (wid, hgt, bpp: INTEGER; fullscreen: BOOLEAN): POINTER is
		require
			not_videomode_set: not is_videomode_set
			valid_size: wid > 0 and hgt > 0
			valid_bpp: bpp = 16 or bpp = 24 or bpp = 32
		external "C"
		alias "SDL_SCREEN_set_videomode"
		ensure
			not Result.is_null
		end

	SDL_UpdateRect (ptr: POINTER; x, y, w, h: INTEGER) is
		require
			not ptr.is_null
		external "C use <SDL.h>"
		alias "SDL_UpdateRect"
		end

end -- class SDL_SCREEN_ACCESS
