-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class SDL_SOLID_IMAGE

inherit
	RESIZABLE_IMAGE
	SDL_SCREEN_ACCESS

create
	make

feature {NONE} -- Creation

	make (w, h, r, g, b: INTEGER) is
			-- New solid color surface of `w'x`h' with color (`r',`g',`b')
		do
			width := w
			height := h
			color := screen.get_color (r, g, b)
		end

feature -- Access

	is_compatible (img: IMAGE): BOOLEAN is
		local
			image: SDL_IMAGE
		do
			image ?= img
			Result := image /= Void
		end

	width: INTEGER

	height: INTEGER

feature -- Operations

	show (img: IMAGE; x, y: INTEGER) is
		local
			image: SDL_IMAGE
			r: RECTANGLE
		do
			image ?= img
			r.set_with_size (x, y, width, height)
			image.fillrect (r, color)
		end

	show_region (img: IMAGE; region: RECTANGLE; x, y: INTEGER) is
		local
			image: SDL_IMAGE
			r: RECTANGLE
		do
			image ?= img
			r.set_with_size (x, y, width.min (region.width),
				height.min (region.height))
			image.fillrect (r, color)
		end

	resize(w, h: INTEGER) is
		do
			width := w
			height := h
		end

feature {NONE} -- Internal

	color: INTEGER

end -- class SDL_SOLID_IMAGE
