-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
deferred class FONT
	-- Abstract font

feature -- Access

	is_compatible (i: IMAGE): BOOLEAN is
			-- Can be shown on `i'
		deferred
		end

	new_image (w, h: INTEGER): IMAGE is
			-- New compatible image of `w'x`h'
		require
			w >= 0 and h >= 0
		deferred
		ensure
			is_compatible (Result)
		end

	height: INTEGER is
			-- Height in pixels
		deferred
		end

	spacing: INTEGER
		-- Spacing beetween lines

	show (text: STRING): IMAGE is
			-- Image showing `text'
		require
			text_not_void: text /= Void
		deferred
		ensure
			Result /= Void
			right_size: Result.width = width_of (text) and
				Result.height = height
			is_compatible (Result)
	end

	width_of (text: STRING): INTEGER is
			-- Width of `text' in pixels
		require
			text_not_void: text /= Void
		deferred
		end

	max_chars (text: STRING; w: INTEGER): INTEGER is
			-- maximum chars of `text' that can be display on an image of width `w'
			-- should be redefined if can be done more efficiently.
		require
			text /= Void
			w >= 0
		local
			l, m, r, wl, wm, wr: INTEGER
		do
			wl := 0
			wr := width_of (text)
			if wr <= w then
				Result := text.count
			else
				from
					l := 0
					r := text.count
				invariant
					wl <= w
					wr > w
				variant
					r-l
				until r=l+1 loop
					m := (l+r)//2
					wm := width_of (text.substring (1, m))
					if wm <= w then
						l := m
						wl := width_of (text.substring (1, l))
					else
						r := m
						wr := width_of (text.substring (1, r))
					end
				end
			end
		ensure
			Result >= 0
			width_of (text.substring (1, Result)) <= w
			Result < text.count implies width_of (text.substring (1, Result+1)) > w
		end

feature -- Operations

	show_at (img: IMAGE; x, y: INTEGER; text: STRING) is
			-- show `text' at `img', upper left coordinates at (`x',`y')
		require
			text_not_void: text /= Void
			image_not_void: img /= Void
			is_compatible (img)
			valid_size: img.width >= x and img.height >= y
		deferred
		end

end -- deferred class FONT
