-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class IMAGE_COMPOSITE

inherit
	IMAGE

create
	make

feature {NONE} -- Creation

	make (w, h: INTEGER) is
			-- Create with width `w' and height `h'
		do
			width := w
			height := h
			create images.make (1, 0)
			create xoff.make (1, 0)
			create yoff.make (1, 0)
		end

feature -- Access

	width, height: INTEGER

	is_compatible(img: IMAGE): BOOLEAN is
		local
			i: ITERATOR[IMAGE]
		do
			from
				Result := True
				i := images.get_new_iterator
			until not Result or i.is_off loop
				Result := i.item.is_compatible (img)
				i.next
			end
		end

feature -- Operations

	show (img: IMAGE; x, y: INTEGER) is
		local
			i: ITERATOR[IMAGE]
			ox,oy: ITERATOR[INTEGER]
		do
			from
				i := images.get_new_iterator
				ox := xoff.get_new_iterator
				oy := yoff.get_new_iterator
			until i.is_off loop
				i.item.show (img, x+ox.item, y+oy.item)
				i.next
				ox.next
				oy.next
			end
		end
	
	show_region (img: IMAGE; region: RECTANGLE; x, y: INTEGER) is
		local
			i: ITERATOR[IMAGE]
			ox,oy: ITERATOR[INTEGER]
			r: RECTANGLE
			dx, dy: INTEGER
		do
			from
				i := images.get_new_iterator
				ox := xoff.get_new_iterator
				oy := yoff.get_new_iterator
			until i.is_off loop
				r.set_with_size (ox.item, oy.item, i.item.width, i.item.height)
				r := r*region
				r.translate (-ox.item, -oy.item)
				dx := x + (ox.item - region.x).max (0)
				dy := y + (oy.item - region.y).max (0)
				i.item.show_region (img, r, dx, dy)
				i.next
				ox.next
				oy.next
			end
		end

	add (i: IMAGE; x,y: INTEGER) is
			--  Add image `i' at offset (`x',`y') to composition
		do
			images.add_last (i)
			xoff.add_last (x)
			yoff.add_last (y)
		end

feature {NONE} -- Representation

	images: ARRAY[IMAGE]
		-- Composed images

	xoff: ARRAY[INTEGER]
		-- Horizontal offsets

	yoff: ARRAY[INTEGER]
		-- Vertical offsets

invariant
	images.count = xoff.count and xoff.count = yoff.count

end -- class IMAGE_COMPOSITE