-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class IMAGE_OFFSET
	-- Image with other image inside moved by an offset
	-- Useful for animations

inherit
	IMAGE

create
	make

feature {NONE} -- Creation

	make (img: IMAGE; ofx, ofy: INTEGER) is
			-- make with `img' offset by (`x',`y')
		require
			img /= Void
		do
			image := img
			offset_x := ofx
			offset_y := ofy
			imgrect.set_with_size (offset_x, offset_y, image.width, image.height)
		end

feature -- Access

	width: INTEGER is
		do
			Result := image.width+offset_x
		end

	height: INTEGER is
		do
			Result := image.height+offset_y
		end

	is_compatible(img: IMAGE): BOOLEAN is
		do
			Result := image.is_compatible(img)
		end

feature -- Operations

	show (img: IMAGE; x, y: INTEGER) is
			-- Blit onto `img' at (`x', `y')
		do
			image.show (img, x+offset_x, y+offset_y)
		end

	show_region (img: IMAGE; region: RECTANGLE; x, y: INTEGER) is
			-- Display `region' at `d' at (`x',`y')
		local
			r, s: RECTANGLE
			dx, dy: INTEGER
		do
			r := region * imgrect
			r.translate (-offset_x, -offset_y)
			dx := x + (offset_x - region.x).max (0)
			dy := y + (offset_y - region.y).max (0)
			image.show_region (img, r, dx, dy)
		end

feature {NONE} -- Representation

	image: IMAGE
		-- Real image shown

	imgrect: RECTANGLE
		-- Rectangle covered by `image'

	offset_x, offset_y: INTEGER
		-- Displacement from the origin

invariant
	image /= Void
end -- class IMAGE_OFFSET
