-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class BOX

inherit
	WINDOW
		redefine
			redraw,
			handle_event
		end
	KEYBOARD_CONSTANTS
		export {NONE} all end

create
	make

feature -- Redefined features

	redraw (r: RECTANGLE) is
		local
			red, blue: INTEGER
			l: SDL_LINE_IMAGE
		do
			if has_focus then red := 255 else blue := 255 end
			show_image (create {SDL_SOLID_IMAGE}.make (width, height, red, 0, blue),
				0, 0, r)
			create l.make(0, 0, width-4, height-4, blue, 0, red)
			l.set_dash(a)
			show_image (l, 2, 2, r)
			Precursor (r)
		end

	handle_event (event: EVENT) is
		local
			b: EVENT_MOUSE_BUTTON
			f: EVENT_FOCUS
			e: EVENT_KEY
		do
			b ?= event
			if not event.handled and b /=Void and then b.state then
				grab
				b.set_handled
			end
			f ?= event
			if not event.handled and f /=Void then
				request_redraw_all
			end
			Precursor (event)
			e ?= event
			if not event.handled and e /= Void and then e.state then
				if e.modifier /= 0 then
					inspect e.symbol
					when key_up then
						if height>10 then resize (0, -10) end
					when key_down then
						resize (0, 10)
					when key_left then
						if width>10 then resize (-10, 0) end
					when key_right then
						resize (10, 0)
					else
					end
				else
					inspect e.symbol
					when key_up then
						move_rel (0, -10)
					when key_down then
						move_rel (0, 10)
					when key_left then
						move_rel (-10, 0)
					when key_right then
						move_rel (10, 0)
					else
					end
				end
			end
		end

feature {NONE} -- Internal

	a: ARRAY[INTEGER] is
		once
			create Result.make(0, 1)
			Result.put(5, 0)
			Result.put(5, 1)
		end


	move_rel (dx, dy: INTEGER) is
		local
			r: RECTANGLE
		do
			r := location
			r.translate (dx, dy)
			move (r)
		end

	resize (dw, dh: INTEGER) is
		local
			r: RECTANGLE
		do
			r.set_with_size (location.x, location.y, width+dw, height+dh)
			move (r)
		end

end -- class BOX
