-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class BOX_CONTAINER

inherit
	WINDOW
		redefine
			make,
			handle_event,
			redraw
		end
	KEYBOARD_CONSTANTS
		export {NONE} all end

create
	make

feature -- Redefined features

	make (w: WINDOW; pos: RECTANGLE) is
		do
			Precursor (w, pos)
			last_pos.set_with_size (0, 0, 120, 40)
		end

	handle_event (event: EVENT) is
		local
			e: EVENT_KEY
		do
			e ?= event
			if not event.handled and e /= Void and then e.state then
				inspect e.symbol
				when key_insert then
					make_child
				when key_delete then
					kill_child
				when key_tab then
					next_child
				else
				end
			end
			Precursor (event)
		end

	redraw (r: RECTANGLE) is
		do
			show_image (create {SDL_SOLID_IMAGE}.make (r.width, r.height, 0, 0, 0),
				r.x, r.y, r)
			Precursor (r)
		end

feature {NONE} -- Internal

	last_pos: RECTANGLE

	make_child is
		local
			w: BOX
		do
			create w.make (Current, last_pos)
			last_pos.translate (10, 10)
		end

	next_child is
		local
			i: INTEGER
		do
			if selected_child /= Void then
				i := children.index_of (selected_child) - 1
				if i < children.lower then i := children.upper end
			else
				i := children.upper
			end
			if children.valid_index (i) then
				(children @ i).grab
			end
		end

	kill_child is
		local
			w: WINDOW
		do
			w := selected_child
			next_child
			if w /= Void then
				w.remove
			end
		end

end -- class BOX_CONTAINER