-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class BOX_VIEWPORT

inherit
	WINDOW
		redefine redraw, make end

create
	make

feature -- Scrollbar handle

	set_pos (p: INTEGER) is
		require
			p.in_range(boxes.lower, boxes.upper)
		do
			if p /= pos then
				pos := p
				request_redraw_all
			end
		end

feature {NONE} -- Creation

	make (w: WINDOW; r: RECTANGLE) is
		local
			img: SDL_SOLID_IMAGE
			i: INTEGER
		do
			Precursor(w, r)
			create boxes.make(0, 25)
			create rand.make
			from i := 0 until i > 25 loop
				create img.make(width, (height / (page_size + 1) - 2).rounded, any_char, any_char, any_char)
				boxes.put(img, i)
				i := i + 1
			end
		end

feature {NONE} -- Internal

	rand: STD_RAND

	any_char: INTEGER is
		do
			rand.next
			Result := rand.last_integer(256) - 1
		end

	pos: INTEGER

feature

	boxes: ARRAY[SDL_SOLID_IMAGE]

	redraw (area: RECTANGLE) is
		local
			i: INTEGER
		do
			from i := 0
			until i > page_size
			loop
				show_image(boxes @ (i + pos), 0, (height * i / (page_size + 1)).rounded, area)
				i := i + 1
			end
		end

	page_size: INTEGER is 4

end -- class BOX_VIEWPORT