-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class SCROLL_TEST

create
	make

feature {NONE} -- Creation

	d: DISPLAY

	new_img (fn: STRING): IMAGE is
		do
			create {SDL_IMAGE}Result.make_from_file (fn)
		end

	new_brick (w, h, r, g, b: INTEGER): RESIZABLE_IMAGE is
		do
			create {SDL_SOLID_IMAGE}Result.make(w, h, r, g, b)
		end

	make is
		local
			w: WINDOW
			l: LABEL
			bg: WINDOW_IMAGE
			w1: BOX_VIEWPORT
			s: V_SCROLLBAR
			h: DRAG_HANDLE
			r: RECTANGLE
			f: FONT
		do
			-- Init video
			create {SDL_DISPLAY}d.make (640,480, 16, False)

			-- Set Pointer
			d.root.set_pointer (create {MOUSE_POINTER}.make (new_img ("cursor1.png"), 6, 4))

			-- Set font
			create {SDL_BITMAP_FONT}f.make("default_font.png")
			d.set_default_font(f)

			-- Black background
			create bg.make(d.root, 0, 0, new_brick(d.root.width, d.root.height, 0, 0, 0))

			-- Window
			r.set_with_size(100, 100, 115, 100)
			create w.make(d.root, r)

			-- Titlebar
			r.set_with_size(0, 0, 115, 15)
			create l.make(w, r, "Drag, Scroll, Enjoy")

			-- Drag handle
			create h.make(w, r)

			-- Viewport
			r.set_with_size(0, 15, 100, 85)
			create w1.make (w, r)

			-- Scrollbar
			r.set_with_size(100, 15, 15, 85)
			create s.make(w, r, new_brick(0, 0, 30, 30, 250))
			s.set_first_button_images(new_brick(15, 15, 200, 0, 0), new_brick(15, 15, 0, 200, 0), new_brick(15, 15, 0, 0, 200))
			s.set_second_button_images(new_brick(15, 15, 200, 0, 0), new_brick(15, 15, 0, 200, 0), new_brick(15, 15, 0, 0, 200))
			s.set_limits(w1.boxes.lower, w1.boxes.upper, w1.page_size)
			s.set_increments(1, 4)
			r.set_with_size(2, 17, 11, 51)
			s.set_trough(r)
			s.set_change_handler(agent w1.set_pos)
			s.set_value(w1.boxes.lower)

			d.do_event_loop
			d.close
		end

end -- class SCROLL_TEST
