-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class BUTTON_IMAGE

inherit
	BUTTON
		rename
			make as button_make
		redefine
			redraw, set_state
		end

create
	make

feature {NONE} -- Creation

	make (w: WINDOW; x, y: INTEGER; i1, i2, i3: IMAGE) is
			-- New button with images `i1', `i2', `i3' for normal, prelight and
			-- pressed states
		local
			r: RECTANGLE
		do
			r.set_with_size (x, y,
				(i1.width).max (i2.width).max (i3.width),
				(i1.height).max (i2.height).max (i3.height))
			imgs := <<i1, i2, i3>>
			imgs.reindex (st_normal)
			button_make (w, r)
		end

feature -- Redefined features

	redraw (area: RECTANGLE) is
		do
			show_image (imgs @ state, 0, 0, area)
			Precursor (area)
		end

feature -- Operations

	set_normal_image(i: IMAGE) is
			-- Updates image for normal state and resizes accordingly
		local
			r: RECTANGLE
		do
			if i /= imgs@st_normal and state = st_normal and display /= Void then
				request_redraw_all
			end
			imgs.put(i, st_normal)
			r.set_with_size(location.x, location.y, i.width.max((imgs@st_prelight).width.max((imgs@st_pressed).width)), i.height.max((imgs@st_prelight).height.max((imgs@st_pressed).height)))
			move(r)
		end

		set_prelight_image(i: IMAGE) is
			-- Updates image for prelight state and resizes accordingly
		local
			r: RECTANGLE
		do
			if i /= imgs@st_prelight and state = st_prelight and display /= Void then
				request_redraw_all
			end
			imgs.put(i, st_prelight)
			r.set_with_size(location.x, location.y, i.width.max((imgs@st_normal).width.max((imgs@st_pressed).width)), i.height.max((imgs@st_normal).height.max((imgs@st_pressed).height)))
			move(r)
		end

		set_pressed_image(i: IMAGE) is
				-- Updates image for pressed state and resizes accordingly
			local
				r: RECTANGLE
			do
				if i /= imgs@st_pressed and state = st_pressed and display /= Void then
					request_redraw_all
				end
				imgs.put(i, st_pressed)
				r.set_with_size(location.x, location.y, i.width.max((imgs@st_normal).width.max((imgs@st_prelight).width)), i.height.max((imgs@st_normal).height.max((imgs@st_prelight).height)))
				move(r)
			end

feature {NONE} -- Internal

	set_state (new_state: INTEGER) is
			-- Change state to `new_state'
		local
			old_state: INTEGER
		do
			old_state := state
			Precursor (new_state)
			-- display is checked for Void, because this is called on creattion
			if state /= old_state and display /= Void then
				request_redraw_all
			end
		end

feature {NONE} -- Representation

	imgs: ARRAY [IMAGE]
		-- Button picture for each state

end -- class BUTTON_IMAGE
