-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class BUTTON_TOGGLE_IMAGE

inherit
	BUTTON_TOGGLE
		rename make as button_make
		redefine set_state, redraw
		end
	BUTTON_IMAGE
		rename make as make_with_3_pics
		redefine set_state, redraw
		end

create
	make

feature {NONE} -- Creation

	make (w: WINDOW; x, y: INTEGER; i1, i2, i3, i4, i5, i6: IMAGE) is
			-- Create button with images i1, i2, i3, i4, i5, i6 for normal 
			-- inactive, prelight inactive, pressed inactive, normal active, 
			-- prelight active, pressed active states respectively.
		local
			r: RECTANGLE
		do
			imgs := <<i1, i2, i3, i4, i5, i6>>
			imgs.reindex (st_normal)
			recalculate_size
			r.set_with_size (x, y, total_width, total_height)
			button_make (w, r)
		end

feature -- Operations

	set_normal_active_image(i: IMAGE) is
			-- Updates image for normal active state and resizes accordingly
		local
			r: RECTANGLE
		do
			if i /= imgs@(st_normal + 3) and state = st_normal 
				and is_active and display /= Void then
				request_redraw_all
			end
			imgs.put(i, st_normal + 3)
			recalculate_size
			r.set_with_size(location.x, location.y, total_width, total_height)
			move(r)
		end

	set_prelight_active_image(i: IMAGE) is
			-- Updates image for active prelight state and resizes accordingly
		local
			r: RECTANGLE
		do
			if i /= imgs@(st_prelight + 3) and state = st_prelight 
				and is_active and display /= Void then
				request_redraw_all
			end
			imgs.put(i, st_prelight + 3)
			recalculate_size
			r.set_with_size(location.x, location.y, total_width, total_height)
			move(r)
		end

	set_pressed_active_image(i: IMAGE) is
			-- Updates image for pressed state and resizes accordingly
		local
			r: RECTANGLE
		do
			if i /= imgs@(st_pressed + 3) and state = st_pressed 
				and is_active and display /= Void then
				request_redraw_all
			end
			imgs.put(i, st_pressed + 3)
			recalculate_size
			r.set_with_size(location.x, location.y, total_width, total_height)
			move(r)
		end

feature

	redraw (area: RECTANGLE) is
		do
			show_image (imgs @ (state + 3 * is_active.to_integer), 0, 0, area)
			Precursor {BUTTON_TOGGLE}(area)
		end

feature {NONE} -- Internal

	total_width: INTEGER

	total_height: INTEGER

	recalculate_size is
		local
			i: INTEGER
		do
			from
				i := imgs.lower
				total_width := 0
			until i > imgs.upper loop
				total_width := total_width.max ((imgs @ i).width)
				i := i + 1
			end
			from
				i := imgs.lower
				total_height := 0
			until i > imgs.upper loop
				total_height := total_height.max ((imgs @ i).height)
				i := i + 1
			end
		end

feature {NONE}

	set_state (new_state: INTEGER) is
			-- Change state to `new_state'
		local
			old_state: INTEGER
		do
			Precursor {BUTTON_TOGGLE} (new_state)
			if state /= old_state and display /= Void then
				request_redraw_all
			end
		end

end -- class BUTTON_TOGGLE_IMAGE
