-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class DRAG_HANDLE
	-- Handle for dragging windows

inherit
	WINDOW
		redefine handle_event end

create
	make

feature {NONE} -- Internal

	is_grabbed: BOOLEAN
		-- Is user grabbing handle?

	mx, my: INTEGER

feature -- Redefined features

	handle_event (event: EVENT) is
		local
			b: EVENT_MOUSE_BUTTON
			m: EVENT_MOUSE_MOVE
			n: EVENT_MOUSE_NOTIFY
			r: RECTANGLE
		do
			Precursor (event)
			if not event.handled then
				m ?= event
				if m /= Void and then is_grabbed then
					r := parent.location
					r.translate (m.x - mx, m.y - my)
					r.set_with_size(r.x.min(parent.parent.width - parent.width).max(0),
						r.y.min(parent.parent.height - parent.height).max(0),
						r.width, r.height)
					parent.move (r)
					event.set_handled
				else
					b ?= event
					if b /= Void and then b.button = 1 then
						if b.state then
							if pre_drag_trigger /= Void then
								pre_drag_trigger.call([])
							end
							mx := b.x
							my := b.y
							is_grabbed := True
						else
							if post_drag_trigger /= Void then
								post_drag_trigger.call([])
							end
							is_grabbed := False
						end
						event.set_handled
					else
						n ?= event
						if n /= Void and then not n.is_enter then
							if post_drag_trigger /= Void then
								post_drag_trigger.call([])
							end
							is_grabbed := False
						end
					end
				end
			end
		end

feature -- Optimization Optional configuration

	set_pre_drag (p: PROCEDURE[ANY, TUPLE]) is
			-- Define a procedure to be called before dragging, that disables
			-- any heavy redrawing on handled window.
		do
			pre_drag_trigger := p
		end

	set_post_drag (p: PROCEDURE[ANY, TUPLE]) is
			-- Define a procedure called after dragging, to put things back
			-- to normal
		do
			post_drag_trigger := p
		end

feature {NONE} -- Implementation

	pre_drag_trigger, post_drag_trigger: PROCEDURE[ANY, TUPLE]
		-- procedures used to disable heavy redrawing features within
		-- window, to accelerate dragging

end -- class DRAG_HANDLE