-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class LABEL

inherit
	TEXT_CONSTANTS
	LABEL_COMMON
		redefine redraw end

create
	make

feature {NONE} -- Creation

	make (w: WINDOW; where: RECTANGLE; t:STRING) is
		do
			make_window (w, where)
			set_text (t)
			set_h_alignment (horz_align_center)
			set_v_alignment (vert_align_center)
		end

feature -- Operations

	set_alignment(horz, vert: REAL) is
		obsolete "use set_h_alignment and/or set_v_alignment instead"
		require
			horz.in_range(0, 1)
			vert.in_range(0, 1)
		do
			set_h_alignment (horz)
			set_v_alignment (vert)
		end

	set_border_width (b: INTEGER) is
			-- leave a `b' pixel margin around text
		do
			border_width := b
			request_redraw_all
		end

	set_bg (new_bg: IMAGE) is
			-- Put `new_bg' as background
		do
			bg := new_bg
			request_redraw_all
		end

	set_hoffset (h: INTEGER) is
			-- Set horizontal offset to `h'
		do
			hoffset := h
		end

feature -- Access

	hoffset: INTEGER
		-- Horizontal offset. Label display is shifted left by `hoffset' pixels.

	border_width: INTEGER

	text_width: INTEGER is
			-- Width of the full text in the current font
		do
			if not dirty then Result := pic.width
			elseif actual_font /= Void then
				Result := actual_font.width_of (text)
			end
		end

feature -- Redefined features

	redraw (area: RECTANGLE) is
		local
			rect: RECTANGLE
		do
			if bg /= Void then show_image (bg, 0, 0, area) end
			if actual_font /= Void then
				if dirty then
					pic := actual_font.show (text)
					dirty := False
				end
				rect.set_with_size (border_width, border_width,
					width-2*border_width, height-2*border_width)
				show_image (pic, left_margin-hoffset, top_margin, rect*area)
				Precursor (area)
			end
		end

feature {NONE} -- Representation

	bg: IMAGE

feature {NONE} -- Internal

	left_margin: INTEGER is
		do
			Result := ((width - text_width - 2 * border_width) * h_alignment + border_width).rounded
		end

	top_margin: INTEGER is
		require
			actual_font /= Void
		do
			Result := ((height - actual_font.height - 2 * border_width) * v_alignment + border_width).rounded
		end

end -- class LABEL