-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
deferred class LABEL_COMMON

inherit
	WINDOW
		rename make as make_window end

feature -- Operations

	set_font (new_font: FONT) is
			-- Change current font to `new_font', or to `display.default_font'
			-- when `Void' is used.
		do
			font := new_font
			dirty := True
			request_redraw_all
		ensure
			font = new_font
		end

	set_text (t: STRING) is
			-- Set displayed text to `t'
		require
			t /= Void
		do
			text := t.twin
			dirty := True
			request_redraw_all
		end

	set_h_alignment (h: REAL) is
			-- Set horizontal alignment to `h'. 0=left to 1=right
		require
			h.in_range (0, 1)
		do
			h_alignment := h
			dirty := true
			request_redraw_all
		ensure
			h_alignment = h
		end

	set_v_alignment (v: REAL) is
			-- Set horizontal alignment to `v'. 0=top to 1=bottom
		require
			v.in_range (0, 1)
		do
			v_alignment := v
			dirty := true
			request_redraw_all
		ensure
			v_alignment = v
		end

feature -- Access

	font: FONT

feature {NONE} -- Representation

	h_alignment: REAL
		-- Horizontal alignment (0=left, 1=right)

	v_alignment: REAL
		-- Vertical alignment (0=top, 1=bottom)

	pic: IMAGE

	dirty: BOOLEAN
		-- True when `text' is not in `pic'

	text: STRING

feature {NONE} -- Internal

	actual_font: FONT is
		do
			if font /= Void then
				Result := font
			else
				Result := display.default_font
			end
		end

invariant
	h_alignment.in_range (0, 1)
	v_alignment.in_range (0, 1)

end -- class LABEL_COMMON
