-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class MULTILINE_LABEL
	-- Label spanning multiple lines.

inherit
	LABEL_COMMON
		redefine redraw end

create
	make

feature {NONE} -- Creation

	make (w: WINDOW; where: RECTANGLE; t:STRING) is
		do
			make_window (w, where)
			set_text (t)
			set_wordwrap (True)
		end

feature -- Operations

	set_justify (value: BOOLEAN) is
			-- Enable/disable justify
		do
			justify := value
			dirty := True
			request_redraw_all
		end

	set_wordwrap (value: BOOLEAN) is
			-- Enable/disable breaking in words
		do
			wordwrap := value
			dirty := True
			request_redraw_all
		end

feature -- Redefined features

	redraw (area: RECTANGLE) is
		do
			if actual_font /= Void then
				if dirty then
					update_pic
				end
				show_image (pic, 0, 0, area)
				Precursor (area)
			end
		end

feature {NONE} -- Representation

	justify: BOOLEAN
		-- Text must be expanded to fill horizontal margin

	wordwrap: BOOLEAN
		-- Lines must be cut only on word boundaries if possible.

feature {NONE} -- Internal

	split: ARRAY [STRING] is
			-- `text' splitted in lines
		require
			actual_font /= Void
		local
			c: STRING
			i, p: INTEGER
			e: STRING
		do
			create Result.make (1, 0)
			from c := text.twin variant c.count until
				c.is_empty
			loop
				p := actual_font.max_chars (c, width).max (1)
				if wordwrap and p < c.count then
					i := p
					from until
						p=0 or else ((c @ p).is_separator and not (c @ (p+1)).is_separator)
					loop p := p - 1 end
					if p = 0 then p := i end
				end
					check p > 0 end
				e := c.substring (1, p)
				i := e.index_of ('%N', 1)
				if i /= 0 then
					p := i
					e := c.substring (1, p-1)
				end
				if wordwrap then e.right_adjust end
				Result.add_last (e)
				c. remove_first (p)
			end
		end

	update_pic is
		require
			actual_font /= Void
		local
			i: ITERATOR [STRING]
			lines: ARRAY [STRING]
			y: INTEGER
			f: FONT
		do
			f := actual_font
			pic := f.new_image (width, height)
			lines := split
			i := lines.get_new_iterator
			from
				i.start
				y := ((height-lines.count*(f.height+f.spacing))*v_alignment).rounded
			until i.is_off or y > height loop
				f.show_at (pic, (h_alignment*(width-f.width_of (i.item))).rounded,
					y, i.item)
				y := y + f.height + f.spacing
				i.next
			end
			dirty := False
		end

end -- class MULTILINE_LABEL
