-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class V_SCROLLBAR
	-- Vertical Scrollbar Widget

inherit
	SCROLLBAR
	redefine handle_event end

create
	make

feature -- Operations

	set_first_button_images (i1, i2, i3: IMAGE) is
		do
			create first_button.make(Current, 0, 0, i1, i2, i3)
			first_button.set_click_handler(agent click_up_handler)
		end

	set_second_button_images (i1, i2, i3: IMAGE) is
		local
			r: RECTANGLE
		do
			create second_button.make(Current, 0, 0, i1, i2, i3)
			r.set_with_size(0, Current.height - second_button.height,
						second_button.width, second_button.height)
			second_button.move(r)
			second_button.set_click_handler(agent click_down_handler)
		end

	handle_event (event: EVENT) is
		local
			b: EVENT_MOUSE_BUTTON
			m: EVENT_MOUSE_MOVE
			n: EVENT_MOUSE_NOTIFY
		do
			Precursor (event)
			if not event.handled then
				m ?= event
				if m /= Void then
					if clicked_on_slidebar then
						slidebar_y := (m.y - drag_y).max(0).min(trough.height - slidebar.height)
						request_redraw(trough)
					end
				else
					b ?= event
					if b /= Void then
						if b.button = 1 then
							if b.state then
								if b.y >= trough.y + slidebar_y and b.y <= trough.y + slidebar_y + slidebar.height then
									clicked_on_slidebar := True
									drag_y := b.y - slidebar_y
								else
									clicked_in_trough := True
								end
							else
								if clicked_on_slidebar then
									set_value(pos_from_slidebar)
									clicked_on_slidebar := false
								elseif clicked_in_trough then
									if b.y < trough.y + slidebar_y then
										set_value(pos_decrease_page)
									elseif b.y > trough.y + slidebar_y + slidebar.height then
										set_value(pos_increase_page)
									end
									clicked_in_trough := false
								end
							end
							event.set_handled
						end
					else
						n ?= event
						if n /= Void then
							if not n.is_enter then
								clicked_in_trough := False
								if clicked_on_slidebar then
									set_value(pos_from_slidebar)
									clicked_on_slidebar := false
								end
							end
							event.set_handled
						end
					end
				end
			end
		end

feature {NONE} -- Callbacks

	click_up_handler is
		do
			set_value((value - step_increment).max(lower))
		end

	click_down_handler is
		do
			set_value((value + step_increment).min(upper - page_size))
		end

feature {NONE} -- Internal

	resize_slidebar is
		do
			slidebar.resize(trough.width, ((page_size * trough.height) / (upper - lower)).rounded)
			slidebar_y := (((value - lower) * trough.height) / (upper - lower)).rounded
		end

	drag_y: INTEGER

	pos_increase_page: INTEGER is
		do
			Result := (value + page_increment).min(upper - page_size)
		end

	pos_decrease_page: INTEGER is
		do
			Result := (value - page_increment).max(lower)
		end

	pos_from_slidebar: INTEGER is
		do
			Result := (slidebar_y * (upper - page_size) / (trough.height - slidebar.height)).rounded
		end

	clicked_in_trough, clicked_on_slidebar: BOOLEAN

invariant
	not (clicked_in_trough and clicked_on_slidebar)
end -- V_SCROLLBAR


