-- EWS (Eiffel Windowing System) - A small OO windowing system
-- Copyright (C) 2004  Daniel F. Moisset, Anthony Lenton
--
--    This library is free software; you can redistribute it and/or
--    modify it under the terms of the GNU Library General Public
--    License as published by the Free Software Foundation; either
--    version 2 of the License, or (at your option) any later version.
--
--    This library is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
--    Library General Public License for more details.
--
--    You should have received a copy of the GNU Library General Public
--    License along with this library; if not, write to the 
--    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
--    Boston, MA  02111-1307  USA.
--
--  Author's email: dmoisset@grulic.org.ar
--  Snail mail address: Pirovano 196, 5000 Cordoba, Argentina
--
class WINDOW_ANIMATED

inherit
	WINDOW
		rename
			make as make_window
		redefine
			handle_event, redraw
		end

create
	make

feature {NONE} -- Creation

	make (w: WINDOW; x,y: INTEGER; a: ANIMATION) is
			-- Make child for `w', placed at (`x',`y'),  playing `a'
		local
			pos: RECTANGLE
		do
			pos.set_with_size (x, y, a.width, a.height)
			make_window (w, pos)
			animation := a
			request_redraw_all
		end

feature -- Redefined features

	redraw (area: RECTANGLE) is
		do
			show_image (animation.item, 0, 0, area)
			Precursor (area)
		end

	handle_event (event: EVENT) is
			-- Process given event
		local
			tick: EVENT_TIMER
			l: RECTANGLE
			i: IMAGE
		do
			Precursor (event)
			if not event.handled then
				tick ?= event
				if tick /= Void then
					i := animation.item
					animation.next
					if not animation.unchanged then
						request_redraw_all
					end
				end
			end
		end

feature {NONE} -- Representation

	animation: ANIMATION

end -- class WINDOW_ANIMATED